@@ -18,20 +18,8 @@ static GtkWidget *prefs_dialog = NULL;
 static void
 prefs_dialog_button_pressed (GtkDialog *dialog, gint id, gpointer data)
 {
-    if (id == GTK_RESPONSE_HELP)
-    {
-        GError* error = 0;
-        if (!g_app_info_launch_default_for_uri("help:gnome-system-monitor/gnome-system-monitor-prefs", NULL, &error))
-        {
-            g_warning("Could not display preferences help : %s", error->message);
-            g_error_free(error);
-        }
-    }
-    else
-    {
-        gtk_widget_destroy (GTK_WIDGET (dialog));
-        prefs_dialog = NULL;
-    }
+    gtk_widget_destroy (GTK_WIDGET (dialog));
+    prefs_dialog = NULL;
 }
 
 
